/**
 * An echo server listening on the port specified in the command line. 
 * This server reads from the client and echoes back the result. When the 
 * client enters the string  "bye\r\n", the server closes the connection.
 */

import java.net.*;
import java.io.*;

public class  EchoServerSeq
{
	public static void main(String[] args) throws IOException {
		if (args.length < 1) {
			System.err.println("Usage: java EchoServer &lt;Port Number&gt;  ");
			System.exit(0);
		}

		ServerSocket sock = null;

		try {
			// establish the socket
			sock = new ServerSocket(Integer.parseInt(args[0]));

			/**
			 * listen for new connection requests.
			 * when a request arrives, service it
			 * and resume listening for more requests. 
			 */
			while (true) {
				// now listen for connections
				Socket client = sock.accept();	

				// service the connection 
				ServiceConnection(client);
			}
		}
		catch (IOException ioe) {
			System.err.println(ioe);
		}
		finally {
			if (sock != null)
				sock.close();
		}
	}

        public static void ServiceConnection(Socket client)
        {
		BufferedReader networkBin = null;
		OutputStreamWriter networkPout = null;
		
		try {
			/**
			 * get the input and output streams associated with the socket.
			 */
			networkBin = new BufferedReader(new InputStreamReader(client.getInputStream()));
			networkPout = new OutputStreamWriter(client.getOutputStream());

			/**
			 * the following successively reads from the input stream and returns
			 * what was read. The loop terminates with ^D or the string "bye\r\n"
			 * from the  input stream.
			 */
			while (true) {
				String line = networkBin.readLine();
				if ( (line == null) || line.equals("bye")) {
					break;
				}
				networkPout.write("Server [ "+line+" ]\r\n");
				networkPout.flush();
			}
		}
		catch (IOException ioe) {
			System.err.println(ioe);
		}
		finally {
			try {
				if (networkBin != null)
					networkBin.close();
				if (networkPout != null)
					networkPout.close();
				if (client != null)
					client.close();
			}
			catch (IOException ioee) {
				System.err.println(ioee);
			}
		} // end try
	} // end ServiceConnection
}





